CameraNotifier class
Предупреждает о попадании в зону действия дорожной камеры.
- Implemented types
- Available extensions
Constructors
- CameraNotifier(Model model)
-
Расширение навигатора, которое предупреждает о попадании в зону действия дорожной камеры.
factory
-
CameraNotifier.fromMessage(ClassMessage<
CameraNotifier> message) -
factory
Properties
- cameraProgress → CameraProgressInfo?
-
Прогресс прохождения зоны действия дорожной камеры.
no setter
-
cameraProgressChannel
→ StatefulChannel<
CameraProgressInfo?> -
Прогресс прохождения зоны действия дорожной камеры.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
message(
) → ClassMessage< CameraNotifier> -
Available on CameraNotifier, provided by the CameraNotifierToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override