Circle class

Окружность.

Inheritance
Implemented types
Available extensions

Constructors

Circle(CircleOptions options)
factory
Circle.fromMessage(ClassMessage<Circle> message)
factory

Properties

bounds GeoRect
Прямоугольник минимального размера, содержащий геометрию.
no setterinherited
color Color
Цвет заливки окружности.
getter/setter pair
dashedStrokeOptions DashedStrokeCircleOptions?
Получение параметров пунктирной обводки
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isVisible bool
getter/setter pairinherited
levelId LevelId?
Получение привязки объекта к этажу в здании.
getter/setter pairinherited
position GeoPoint
Местоположение центра окружности.
getter/setter pair
radius Meter
Радиус окружности.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color
Цвет границы окружности.
getter/setter pair
strokeWidth LogicalPixel
Ширина линии границы окружности.
getter/setter pair
userData Object?
Произвольные пользовательские данные, прикрепленные к объекту.
getter/setter pairinherited
zIndex ZIndex
Получение уровня отрисовки объекта.
getter/setter pairinherited

Methods

message() ClassMessage<Circle>

Available on Circle, provided by the CircleToClassMessage extension

message() ClassMessage<MapObject>

Available on MapObject, provided by the MapObjectToClassMessage extension

message() ClassMessage<SimpleMapObject>

Available on SimpleMapObject, provided by the SimpleMapObjectToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override