ClosingSoon class

Скоро закроется.

Constructors

ClosingSoon({required Duration timeUntilClose, required ClosedReason reason})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
reason ClosedReason
Причина, по которой организация будет закрыта.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeUntilClose Duration
Время до закрытия.
final

Methods

copyWith({Duration? timeUntilClose, ClosedReason? reason}) ClosingSoon
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override