CoordinatesFollowController class

Контроллер слежения за координатами позиции карты.

Inheritance
Implemented types
Available extensions

Constructors

CoordinatesFollowController([Duration animationDuration = const Duration(milliseconds: 1000), Meter valueThreshold = const Meter(0.10000000149011612)])
Создание контроллера слежения за координатами позиции карты.
factory
CoordinatesFollowController.fromMessage(ClassMessage<CoordinatesFollowController> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<CoordinatesFollowController>

Available on CoordinatesFollowController, provided by the CoordinatesFollowControllerToClassMessage extension

message() ClassMessage<FollowController>

Available on FollowController, provided by the FollowControllerToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override