DirectMapRotationEvent class

Событие прямого вращения карты. О событиях прямого управления картой описано в DirectMapControlBeginEvent.

Inheritance
Implemented types
Available extensions

Constructors

DirectMapRotationEvent(Bearing bearingDelta, Duration timestamp, [ScreenPoint? rotationCenter = null])
  • Parameter bearingDelta: изменение угла поворота карты, в градусах. Положительные значения соответствуют направлению вращения против часовой стрелки
  • Parameter timestamp: Время генерации системного события.
  • Parameter rotationCenter: Точка на экране, вокруг которой вращается карта. Если точка не задана, то вращение происходит относительно точки позиции карты.
  • factory
    DirectMapRotationEvent.fromMessage(ClassMessage<DirectMapRotationEvent> message)
    factory

    Properties

    bearingDelta Bearing
    Изменение угла поворота карты.
    no setter
    hashCode int
    The hash code for this object.
    no setteroverride
    rotationCenter ScreenPoint?
    Точка на экране, вокруг которой вращается карта.
    no setter
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    timestamp Duration
    Получение времени регистрации события ввода.
    no setterinherited

    Methods

    message() ClassMessage<DirectMapRotationEvent>

    Available on DirectMapRotationEvent, provided by the DirectMapRotationEventToClassMessage extension

    message() ClassMessage<Event>

    Available on Event, provided by the EventToClassMessage extension

    message() ClassMessage<InputEvent>

    Available on InputEvent, provided by the InputEventToClassMessage extension

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    override