DynamicRouteInfoSettings class

Настройки получения динамических данных о маршруте.

Implemented types
Available extensions

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatePeriod Duration
Периодичность, с которой должны обновляться динамические данные о маршруте.
getter/setter pair

Methods

message() ClassMessage<DynamicRouteInfoSettings>

Available on DynamicRouteInfoSettings, provided by the DynamicRouteInfoSettingsToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override