ExcludedAreaType enum

Тип исключаемой области.

Inheritance
Available extensions

Values

point → const ExcludedAreaType

Исключаемая область - это окружность с центром в первой точке points и радиусом, равным extent. В points должна находиться ровно одна точка, в противном случае запрос завершится ошибкой.

const ExcludedAreaType(0)
polyline → const ExcludedAreaType

Исключаемая область - это ломаная линия с шириной, равной extent (points - вершины линии).

const ExcludedAreaType(1)
polygon → const ExcludedAreaType

Исключаемая область - это полигон с вершинами в points. При этом от сторон полигона дополнительно делается отступ на extent.

const ExcludedAreaType(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(int value) ExcludedAreaType

Constants

values → const List<ExcludedAreaType>
A constant List of the values in this enum, in order of their declaration.