File class
Идентификатор файла.
Может являться не только файлом на файловой системе, но и произвольным источником данных.
- Implemented types
- Available extensions
Constructors
- File(String path)
-
Файл в файловой системе.
factory
-
File.fromMessage(ClassMessage<
File> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
message(
) → ClassMessage< File> -
Available on File, provided by the FileToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override