FinishDetector class

Implemented types
Available extensions

Constructors

FinishDetector.fromMessage(ClassMessage<FinishDetector> message)
factory

Properties

distanceToFinishInStraightLineLimitMeters double
getter/setter pair
hardLimitMeters RouteDistance
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softLimitMeters RouteDistance
getter/setter pair
vehicleHardLimitMeters RouteDistance
getter/setter pair
vehicleSoftLimitMeters RouteDistance
getter/setter pair

Methods

message() ClassMessage<FinishDetector>

Available on FinishDetector, provided by the FinishDetectorToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override