GeoRect class

Прямоугольная область в сферической системе координат (например, WGS84). Данная структура не привязана к конкретной геодезической системе координат.

Available extensions

Constructors

GeoRect({required GeoPoint southWestPoint, required GeoPoint northEastPoint})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isDegenerate bool

Available on GeoRect, provided by the GeoRectIsDegenerate extension

Проверяет прямоугольник на вырожденность. Если точки в прямоугольнике равны, то он вырождается в точку. Вырожденный прямоугольник является корректным прямоугольником. Некорректный прямоугольник не является вырожденным.
no setter
isGeoRectValid bool

Available on GeoRect, provided by the GeoRectIsGeoRectValid extension

no setter
northEastPoint GeoPoint
Северо-восточная точка, правая верхняя граница прямоугольника.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
southWestPoint GeoPoint
Юго-западная точка, левая нижняя граница прямоугольника.
final

Methods

containsPoint(GeoPoint point) bool

Available on GeoRect, provided by the GeoRectContainsPoint extension

containsRect(GeoRect rect2) bool

Available on GeoRect, provided by the GeoRectContainsRect extension

copyWith({GeoPoint? southWestPoint, GeoPoint? northEastPoint}) GeoRect
expandPoint(GeoPoint point) GeoRect

Available on GeoRect, provided by the GeoRectExpandPoint extension

expandRect(GeoRect rect2) GeoRect

Available on GeoRect, provided by the GeoRectExpandRect extension

intersects(GeoRect rect2) bool

Available on GeoRect, provided by the GeoRectIntersects extension

Пересекаются ли прямоугольники, т.е. имеют общие точки. Прямогольники, с общими точками лишь на границе, так же считаются пересекающимися.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override