IndoorWidget class

Inheritance

Constructors

IndoorWidget({IndoorWidgetColorScheme? light, IndoorWidgetColorScheme? dark, bool showRoof = true, Key? key})
const

Properties

dark IndoorWidgetColorScheme
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
light IndoorWidgetColorScheme
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRoof bool
Determines whether the roof button is displayed. If showRoof == false, the roof button is hidden and the maximum number of visible floors increases to 5.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ThemedMapControllingWidgetState<IndoorWidget, IndoorWidgetColorScheme>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDarkColorScheme → const IndoorWidgetColorScheme
Default color scheme for dark mode.
defaultLightColorScheme → const IndoorWidgetColorScheme
Default color scheme for light mode.