MapManager class

Интерфейс, позволяющий добавлять карты в навигатор и убирать их из него.

Implemented types
Available extensions

Constructors

MapManager.fromMessage(ClassMessage<MapManager> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMap(Map map) → void
message() ClassMessage<MapManager>

Available on MapManager, provided by the MapManagerToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMap(Map map) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override