MapObject class

Объект на карте.

Implemented types
Implementers
Available extensions

Constructors

MapObject.fromMessage(ClassMessage<MapObject> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userData Object?
Произвольные пользовательские данные, прикрепленные к объекту.
getter/setter pair

Methods

message() ClassMessage<MapObject>

Available on MapObject, provided by the MapObjectToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override