MapWidgetColorScheme class abstract

Класс позволяет задать цветовую схему виджета карты. Может иметь любые поля и их значения, необходимые контролу для определения своей цветовой схемы.

Implementers

Constructors

MapWidgetColorScheme()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() MapWidgetColorScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited