MiniMapControlModel class

Интерфейс модели контрола миникарты. Предназначен для управления позицией маркера на экране, зумом и прочим положением камеры так, чтобы маршрут было лучше видно на миникарте.

Implemented types
Available extensions

Constructors

MiniMapControlModel(Context context, Model model, Map map)
factory
MiniMapControlModel.fromMessage(ClassMessage<MiniMapControlModel> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<MiniMapControlModel>

Available on MiniMapControlModel, provided by the MiniMapControlModelToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override