ModelData class

Данные модели.

Implemented types
Available extensions

Constructors

ModelData.fromMessage(ClassMessage<ModelData> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<ModelData>

Available on ModelData, provided by the ModelDataToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override