MyLocationMapObjectSource class

Источник, содержащий маркер геопозиции.

Inheritance
Implemented types
Available extensions

Constructors

MyLocationMapObjectSource(Context context, [MyLocationControllerSettings controllerSettings = const MyLocationControllerSettings(), MyLocationMapObjectMarkerType markerType = MyLocationMapObjectMarkerType.model])
Создать источник маркера геопозиции.
factory
MyLocationMapObjectSource.fromMessage(ClassMessage<MyLocationMapObjectSource> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
item MyLocationMapObject
Получить маркер геопозиции.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<MyLocationMapObjectSource>

Available on MyLocationMapObjectSource, provided by the MyLocationMapObjectSourceToClassMessage extension

message() ClassMessage<Source>

Available on Source, provided by the SourceToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override