MyLocationMapObjectSourceProvider class
Провайдер, предоставляющий источник маркера геопозиции.
- Implemented types
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- myLocationMapObjectSource → MyLocationMapObjectSource
-
Источник, содержащий маркер геопозиции.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
message(
) → ClassMessage< MyLocationMapObjectSourceProvider> -
Available on MyLocationMapObjectSourceProvider, provided by the MyLocationMapObjectSourceProviderToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override