OpenStatus class final

Properties

asClosed Closed?
no setter
asClosingSoon ClosingSoon?
no setter
asOpened Opened?
no setter
asOpeningSoon OpeningSoon?
no setter
hashCode int
The hash code for this object.
no setteroverride
isClosed bool
no setter
isClosingSoon bool
no setter
isOpened bool
no setter
isOpeningSoon bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

match<T>({required T opened(Opened value), required T openingSoon(OpeningSoon value), required T closingSoon(ClosingSoon value), required T closed(Closed value)}) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override