ParkingControlModel class

Модель контрола парковок.

  • Note: Этот интерфейс является потокобезопасным.
Implemented types
Available extensions

Constructors

ParkingControlModel(Map map)
Функция создания модели элемента управления парковками.
factory
ParkingControlModel.fromMessage(ClassMessage<ParkingControlModel> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isEnabled bool
Состояние элемента управления видимостью парковок. true, если парковки видны.
no setter
isEnabledChannel → StatefulChannel<bool>
Состояние элемента управления видимостью парковок. true, если парковки видны.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<ParkingControlModel>

Available on ParkingControlModel, provided by the ParkingControlModelToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggleParkingsVisibility() → void
Действие при нажатии на контрол. Переключает видимость парковок на карте.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override