Polygon class

Полигон на карте.

Inheritance
Implemented types
Available extensions

Constructors

Polygon(PolygonOptions options)
Cоздание полигона на основе параметров.
factory
Polygon.fromMessage(ClassMessage<Polygon> message)
factory

Properties

bounds GeoRect
Прямоугольник минимального размера, содержащий геометрию.
no setterinherited
color Color
getter/setter pair
contours List<List<GeoPoint>>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isVisible bool
getter/setter pairinherited
levelId LevelId?
Получение привязки объекта к этажу в здании.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color
getter/setter pair
strokeWidth LogicalPixel
getter/setter pair
userData Object?
Произвольные пользовательские данные, прикрепленные к объекту.
getter/setter pairinherited
zIndex ZIndex
Получение уровня отрисовки объекта.
getter/setter pairinherited

Methods

message() ClassMessage<MapObject>

Available on MapObject, provided by the MapObjectToClassMessage extension

message() ClassMessage<Polygon>

Available on Polygon, provided by the PolygonToClassMessage extension

message() ClassMessage<SimpleMapObject>

Available on SimpleMapObject, provided by the SimpleMapObjectToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override