RasterTileSource class

Источник, получающий растровые тайлы.

Inheritance
Implemented types
Available extensions

Constructors

RasterTileSource(Context context, String sublayerName, RasterUrlTemplate sourceTemplate)
Создание источника, получающего растровые тайлы.
factory
RasterTileSource.fromMessage(ClassMessage<RasterTileSource> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<RasterTileSource>

Available on RasterTileSource, provided by the RasterTileSourceToClassMessage extension

message() ClassMessage<Source>

Available on Source, provided by the SourceToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOpacity(Opacity opacity) → void
Установка значения прозрачности растрового тайла.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override