RoadEventSource class

Интерфейс класса, управляющего отображением дорожных событий (tUGC) на карте.

Inheritance
Implemented types
Available extensions

Constructors

RoadEventSource(Context context)
Создание источника, отображающего дорожные события на карте.
factory
RoadEventSource.fromMessage(ClassMessage<RoadEventSource> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
highlightedObjects List<DgisObjectId>
Получение списка идентификаторов выделенных дорожных событий.
no setter
highlightedObjectsChannel → StatefulChannel<List<DgisObjectId>>
Получение списка идентификаторов выделенных дорожных событий.
no setter
roadEventFilter RoadEventFilter?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleEvents EnumSet<RoadEventDisplayCategory>
Получение текущих категорий событий, предоставляемых данным источником.
getter/setter pair

Methods

message() ClassMessage<RoadEventSource>

Available on RoadEventSource, provided by the RoadEventSourceToClassMessage extension

message() ClassMessage<Source>

Available on Source, provided by the SourceToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHighlighted(List<DgisObjectId> directoryObjectIds, bool highlighted) → void
Установка или снятие выделения дорожных событий.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override