RouteEditorViewTheme class

Inheritance

Constructors

RouteEditorViewTheme({required Color backgroundColor, required RouteCardTheme cardTheme, required RouteTabTheme tabTheme, required Color headerButtonBackground, required Color headerButtonColor, required TextStyle startLabelTextStyle, required Color startPointColor, required TextStyle finishLabelTextStyle, required Color finishPointColor, required Color routeLineColor, double handleHeight = 16, double routeListHeight = 100, double routeListVerticalPadding = 16, double tabBarHeight = 56, double bottomPadding = 8, double horizontalPadding = 16, double cardWidth = 340, double cardSpacing = 8})
const

Properties

backgroundColor Color
final
bottomPadding double
final
cardSpacing double
final
cardTheme RouteCardTheme
final
cardWidth double
final
finishLabelTextStyle TextStyle
final
finishPointColor Color
final
handleHeight double
final
hashCode int
The hash code for this object.
no setterinherited
headerButtonBackground Color
final
headerButtonColor Color
final
horizontalPadding double
final
routeLineColor Color
final
routeListHeight double
final
routeListVerticalPadding double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLabelTextStyle TextStyle
final
startPointColor Color
final
tabBarHeight double
final
tabTheme RouteTabTheme
final

Methods

copyWith({Color? backgroundColor, RouteCardTheme? cardTheme, RouteTabTheme? tabTheme, Color? headerButtonBackground, Color? headerButtonColor, TextStyle? startLabelTextStyle, Color? startPointColor, TextStyle? finishLabelTextStyle, Color? finishPointColor, Color? routeLineColor, double? handleHeight, double? routeListHeight, double? routeListVerticalPadding, double? tabBarHeight, double? bottomPadding, double? horizontalPadding, double? cardWidth, double? cardSpacing}) RouteEditorViewTheme
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited