RouteRebuilder class

Контроллер поиска нового маршрута при сходе с текущего маршрута.

Implemented types
Available extensions

Constructors

RouteRebuilder.fromMessage(ClassMessage<RouteRebuilder> message)
factory

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<RouteRebuilder>

Available on RouteRebuilder, provided by the RouteRebuilderToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override