RouterErrorCode enum

Категории ошибок поисковиков маршрута.

Inheritance
Available extensions

Values

invalidArgument → const RouterErrorCode

Ошибка пользователя - неправильный аргумент.

const RouterErrorCode(1)
noData → const RouterErrorCode

Отсутствуют региональные данные для оффлайнового поисковика или макрограф.

const RouterErrorCode(2)
startAndFinishTooFar → const RouterErrorCode

Точки старта и финиша находятся слишком далеко друг от друга, построение маршрута невозможно.

const RouterErrorCode(3)
startAndFinishTooClose → const RouterErrorCode

Точки старта и финиша находятся слишком близко друг к другу, построение маршрута невозможно.

const RouterErrorCode(4)
searchBetweenRegionsUnsupported → const RouterErrorCode

Поиск между регионами не поддерживается (например, для оффлайнового поисковика в случае отсутствия макрографа).

const RouterErrorCode(5)
searchForRoutingTypeUnsupported → const RouterErrorCode

Поиск не поддерживается для выбранного типа транспорта (либо оффлайн, либо поиск маршрута на общественном транспорте в глобальном проекте онлайн).

const RouterErrorCode(6)
internalError → const RouterErrorCode

Внутренняя ошибка поисковика маршрута.

const RouterErrorCode(7)
networkError → const RouterErrorCode

Проблема подключения к интернету для онлайн-поисковика.

const RouterErrorCode(8)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByValue(int value) → RouterErrorCode

Constants

values → const List<RouterErrorCode>
A constant List of the values in this enum, in order of their declaration.