RouterType enum

Тип поисковика маршрута.

Inheritance
Available extensions

Values

online → const RouterType

Онлайн поисковик маршрута.

const RouterType(0)
offline → const RouterType

Оффлайн поисковик маршрута.

const RouterType(1)
hybrid → const RouterType

Гибридный онлайн/оффлайн поисковик маршрута.

const RouterType(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(int value) RouterType

Constants

values → const List<RouterType>
A constant List of the values in this enum, in order of their declaration.