SortingType enum

Тип сортировки.

Inheritance
Available extensions

Values

byRelevance → const SortingType

По релевантности. Используется по умолчанию.

const SortingType(0)
byDistance → const SortingType

По расстоянию от текущего положения пользователя.

const SortingType(1)
byRating → const SortingType

По рейтингу.

const SortingType(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(int value) SortingType

Constants

values → const List<SortingType>
A constant List of the values in this enum, in order of their declaration.