Style class

Стиль с набором свойств объектов карты (cм. ISource).

Implemented types
Available extensions

Constructors

Style.fromMessage(ClassMessage<Style> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleAttributes Attributes
Получение свойств по умолчанию для объектов, к которым применён указанный слой.
no setter

Methods

message() ClassMessage<Style>

Available on Style, provided by the StyleToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override