SuggestQuery class

Запрос поисковой подсказки.

Implemented types
Available extensions

Constructors

SuggestQuery.fromMessage(ClassMessage<SuggestQuery> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<SuggestQuery>

Available on SuggestQuery, provided by the SuggestQueryToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override