TrafficRoute class
- Implemented types
- Available extensions
Constructors
-
TrafficRoute.fromMessage(ClassMessage<
TrafficRoute> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- route → Route
-
Маршрут.
no setter
-
routeTollPaymentInfos
→ List<
RouteTollPaymentInfo> -
Информация о стоимости проезда по платным участкам маршрута.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traffic → Traffic
-
Пробочные данные.
no setter
Methods
-
message(
) → ClassMessage< TrafficRoute> -
Available on TrafficRoute, provided by the TrafficRouteToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
- Создание маршрута из десериализованного состояния навигации с добавлением содержащихся в нём объектов в базу дорожных событий (необходимо для отображения событий на маршруте на карте при невозможности получить события онлайн).