TrafficSource class

Интерфейс класса, управляющего отображением пробок на карте.

Inheritance
Implemented types
Available extensions

Constructors

TrafficSource(Context context)
factory
TrafficSource.fromMessage(ClassMessage<TrafficSource> message)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<Source>

Available on Source, provided by the SourceToClassMessage extension

message() ClassMessage<TrafficSource>

Available on TrafficSource, provided by the TrafficSourceToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override