VoiceSelector class
Управляет голосовыми пакетами в текущей сессии навигатора.
- Implemented types
- Available extensions
Constructors
-
VoiceSelector.fromMessage(ClassMessage<
VoiceSelector> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voice ↔ NavigationVoice?
-
Голосовой пакет, с помощью которого воспроизводятся голосовые оповещения в текущей сессии навигатора.
getter/setter pair
Methods
-
message(
) → ClassMessage< VoiceSelector> -
Available on VoiceSelector, provided by the VoiceSelectorToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override