DgisMapObject class
Объект карты 2GIS.
- Note: информацию об объекте можно получить через справочник (directory)
- Inheritance
- Implemented types
- Available extensions
Constructors
-
DgisMapObject.fromMessage(ClassMessage<
DgisMapObject> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → DgisObjectId
-
Стабильный числовой идентификатор объекта.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userData ↔ Object?
-
Произвольные пользовательские данные, прикрепленные к объекту.
getter/setter pairinherited
Methods
-
message(
) → ClassMessage< DgisMapObject> -
Available on DgisMapObject, provided by the DgisMapObjectToClassMessage extension
-
message(
) → ClassMessage< MapObject> -
Available on MapObject, provided by the MapObjectToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override