MapRotationEndEvent class
Событие окончания вращения карты вокруг точки.
- Inheritance
- Implemented types
- Available extensions
Constructors
- MapRotationEndEvent()
-
factory
-
MapRotationEndEvent.fromMessage(ClassMessage<
MapRotationEndEvent> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
message(
) → ClassMessage< Event> -
Available on Event, provided by the EventToClassMessage extension
-
message(
) → ClassMessage< MapRotationEndEvent> -
Available on MapRotationEndEvent, provided by the MapRotationEndEventToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override