NearestPlatform class
Информация о платформе.
Constructors
- NearestPlatform({required DgisObjectId id, required String name, required String? headingTo, required Color? color, required NearestPlatformTransitionType? transitionType})
-
const
Properties
- color → Color?
-
Цветовое кодирование маршрута.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- headingTo → String?
-
Описание направления остановочной платформы.
final
- id → DgisObjectId
-
Уникальный идентификатор остановочной платформы.
final
- name → String
-
Название остановки.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionType → NearestPlatformTransitionType?
-
Тип перехода.
final
Methods
-
copyWith(
{DgisObjectId? id, String? name, Optional< String?> ? headingTo, Optional<Color?> ? color, Optional<NearestPlatformTransitionType?> ? transitionType}) → NearestPlatform -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override