PerformSearchHandler class
Предложено поискать определенный набор объектов.
- Implemented types
- Available extensions
Constructors
-
PerformSearchHandler.fromMessage(ClassMessage<
PerformSearchHandler> message) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchQuery → SearchQuery
-
Запрос для прогона через поисковик.
no setter
Methods
-
message(
) → ClassMessage< PerformSearchHandler> -
Available on PerformSearchHandler, provided by the PerformSearchHandlerToClassMessage extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override