RouterErrorInfo class
Информация об ошибке поисковика маршрута.
Constructors
- RouterErrorInfo({RouterErrorSource source = RouterErrorSource.hybridRouter, RouterErrorCode code = RouterErrorCode.internalError})
-
const
Properties
- code → RouterErrorCode
-
Код ошибки.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → RouterErrorSource
-
Информация об источнике ошибки.
final
Methods
-
copyWith(
{RouterErrorSource? source, RouterErrorCode? code}) → RouterErrorInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override